Stan Math Library: stan/math/fwd/scal/fun/log.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_LOG_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_LOG_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/constants.hpp>
7
8 namespace stan {
9
10 namespace math {
11
12 template <typename T>
13 inline
14 fvar<T>
15 log(const fvar<T>& x) {
16 using std::log;
17 using stan::math::NOT_A_NUMBER;
18 if (x.val_ < 0.0)
19 return fvar<T>(NOT_A_NUMBER, NOT_A_NUMBER);
20 else
21 return fvar<T>(log(x.val_), x.d_ / x.val_);
22 }
23 }
24 }
25 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::NOT_A_NUMBER
const double NOT_A_NUMBER
(Quiet) not-a-number value.
Definition: constants.hpp:56
stan
Definition: log_sum_exp.hpp:8
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::log
var log(const var &a)
Return the natural log of the specified variable (cmath).
Definition: log.hpp:50
constants.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.